q1ss.binalg
===========

.. automodule:: q1ss.binalg

q1ss.binalg.__all__
-------------------

The following members were explicitly reexported using ``__all__``:

    - :py:class:`q1ss.binalg.affine.AffineSubspace`
    - :py:class:`q1ss.binalg.binmat.binmat`
    - :py:class:`q1ss.binalg.binvec.binvec`
